@@ -5,6 +5,8 @@
     GIFT, a flexible content based image retrieval system.
     Copyright (C) 1998, 1999, 2000, 2001, 2002, CUI University of Geneva
 
+     Copyright (C) 2003, 2004 Bayreuth University
+    Copyright (C) 2005,2006 Bamberg University
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
@@ -130,7 +132,7 @@ protected:
   string mFeatureDescriptionFileName;
 
   /** map from feature id to the offset for this feature */
-  typedef HASH_MAP<TID,unsigned int> CIDToOffset;//new hash
+  typedef HASH_MAP<TID,streampos> CIDToOffset;//new hash
   /** map from feature id to the offset for this feature */
   CIDToOffset mIDToOffset;
 
@@ -151,7 +153,7 @@ protected:
       (helper function for inverted file construction)
    */
   void writeOffsetFileElement(TID inFeatureID,
-			      int inPosition,
+			      streampos inPosition,
 			      ostream& inOpenOffsetFile);
   /** loads a *.fts file. and returns the feature list*/
   CDocumentFrequencyList* getFeatureFile(string inFileName)const;
