@@ -5,6 +5,8 @@
     GIFT, a flexible content based image retrieval system.
     Copyright (C) 1998, 1999, 2000, 2001, 2002, CUI University of Geneva
 
+     Copyright (C) 2003, 2004 Bayreuth University
+    Copyright (C) 2005,2006 Bamberg University
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
@@ -106,6 +108,8 @@ public:
   //----------------------------------------
   /** Constructor */
   CAccessorAdmin(CAccessorFactoryContainer& inFactoryContainer);
+  /** destructor */
+  ~CAccessorAdmin();
   /**  */
   string CAccessorAdmin::getAlgorithmIDListID()const;
   /**  */
